==> pokerth_0.7.1.orig.tar.gz: pokerth-0.7.1/src/gui/qt/settingsdialog/manualblindsorderdialog/manualblindsorderdialogimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MANUALBLINDSORDERDIALOGIMPL_H
#define MANUALBLINDSORDERDIALOGIMPL_H

#include "ui_manualblindsorderdialog.h"

#include <QtCore>
#include <QtGui>

class ConfigFile;

class manualBlindsOrderDialogImpl: public QDialog, public Ui::manualBlindsOrderDialog {
Q_OBJECT
public:
    manualBlindsOrderDialogImpl(QWidget *parent = 0, ConfigFile *c = 0);
	
	void exec();

	
public slots:
	bool getSettingsCorrect() const	{ return settingsCorrect;}
	
	void addBlindValueToList();
	void removeBlindFromList();
	void sortBlindsList();

private:
	
	ConfigFile* myConfig;

	bool settingsCorrect;
};

#endif

==> pokerth_0.8.2-4.tar.gz: pokerth-0.8.2/src/gui/qt/settingsdialog/manualblindsorderdialog/manualblindsorderdialogimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MANUALBLINDSORDERDIALOGIMPL_H
#define MANUALBLINDSORDERDIALOGIMPL_H

//--- GUI_800x480 ---
#include "ui_manualblindsorderdialog_800x480.h"
//---
// #include "ui_manualblindsorderdialog.h"
//---

#include <QtCore>
#include <QtGui>

class ConfigFile;

class manualBlindsOrderDialogImpl: public QDialog, public Ui::manualBlindsOrderDialog {
Q_OBJECT
public:
    manualBlindsOrderDialogImpl(QWidget *parent = 0, ConfigFile *c = 0);
	
	void exec();

	
public slots:
	bool getSettingsCorrect() const	{ return settingsCorrect;}
	
	void addBlindValueToList();
	void removeBlindFromList();
	void sortBlindsList();

private:
	
	ConfigFile* myConfig;

	bool settingsCorrect;
};

#endif
